"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const types_1 = require("@typescript-eslint/types");
const util_1 = require("../util");
function isRequire(node) {
    return Boolean((node === null || node === void 0 ? void 0 : node.callee) &&
        node.callee.type === types_1.AST_NODE_TYPES.Identifier &&
        node.callee.name === 'require' &&
        node.arguments.length > 0);
}
function isStaticValue(arg) {
    return (arg.type === types_1.AST_NODE_TYPES.Literal ||
        (arg.type === types_1.AST_NODE_TYPES.TemplateLiteral &&
            arg.expressions.length === 0));
}
exports.default = (0, util_1.createRule)({
    defaultOptions: [],
    name: 'no-commonjs-dynamic-require',
    meta: {
        type: 'suggestion',
        docs: {
            description: 'Using this rule to disable the use of dynamic require for CommonJS or ESM import.',
            recommended: false,
        },
        messages: {
            requireShouldBeLiteral: 'Calls to require() should use string literals',
        },
        schema: [{}],
    },
    create(context) {
        return {
            CallExpression(node) {
                if (
                // eslint-disable-next-line no-extra-boolean-cast
                !Boolean(node.arguments[0]) ||
                    isStaticValue(node.arguments[0])) {
                    return;
                }
                if (isRequire(node)) {
                    context.report({
                        node,
                        messageId: 'requireShouldBeLiteral',
                    });
                    return;
                }
            },
        };
    },
});
//# sourceMappingURL=no-commonjs-dynamic-require.js.map