"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const types_1 = require("@typescript-eslint/types");
const util_1 = require("../util");
/** This function checks for the "module.exports" */
function isModuleExports(node) {
    return Boolean(Boolean(node) &&
        node.object.type === types_1.AST_NODE_TYPES.Identifier &&
        node.object.name === 'module' &&
        node.property.type === types_1.AST_NODE_TYPES.Identifier &&
        node.property.name === 'exports');
}
/** This function Checks if the scope is of type "module" and not script.
 * "script"'s "module.export" is ignored
 */
function isScopeAModule(scope) {
    return scope.variableScope.type === 'module';
}
exports.default = (0, util_1.createRule)({
    defaultOptions: [],
    name: 'no-commonjs-module-exports',
    meta: {
        type: 'suggestion',
        docs: {
            description: 'Prefer ESM export or export default over syntax over CommonJS module.exports.',
            recommended: false,
        },
        messages: {
            noCommonJsModuleExports: (0, util_1.ruleMessageTemplate)({
                why: 'Prefer ESM import/export syntax over CommonJS module.exports and require().',
                linterMessage: 'Expected "export" or "export default" instead of "module.exports"',
            }),
        },
        schema: [],
    },
    create(context) {
        return {
            MemberExpression: function (node) {
                if (isModuleExports(node) &&
                    isScopeAModule(context.getScope())) {
                    context.report({
                        node,
                        messageId: 'noCommonJsModuleExports',
                    });
                }
            },
        };
    },
});
//# sourceMappingURL=no-commonjs-module-exports.js.map