"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
const constants_1 = require("../shared/constants");
function isModuleScope(scope) {
    return scope.variableScope.type === constants_1.CEScopeType.Module;
}
exports.default = (0, util_1.createRule)({
    defaultOptions: [],
    name: 'no-esm-export-default',
    meta: {
        type: 'suggestion',
        docs: {
            description: 'Using this rule to disable the use of dynamic require for CommonJS or ESM import.',
            recommended: false,
        },
        messages: {
            noExportDefault: (0, util_1.ruleMessageTemplate)({
                linterMessage: 'using default export is not allowed',
                why: 'ESM export default causing inconsistent naming and confusion when project still using both ESM and CommonJS.',
            }),
        },
        schema: [{}],
    },
    create(context) {
        return {
            ExportDefaultDeclaration(node) {
                if (isModuleScope(context.getScope())) {
                    context.report({
                        messageId: 'noExportDefault',
                        node,
                    });
                }
            },
        };
    },
});
//# sourceMappingURL=no-esm-export-default.js.map